@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "dime" "0.2.0"
+(define-package "dime" "20260212.8"
   "Dylan interaction mode."
   '((emacs "25.1")
     (dylan "3.0"))
